#
# Copyright (C) 2019-2020 Guillaume Bernard <guillaume.bernard@koala-lms.org>
# Copyright (C) 2020 Louis Barbier <louis.barbier41@outlook.fr>
#
# This file is part of Koala LMS (Learning Management system)

# Koala LMS is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
# We make an extensive use of the Django framework, https://www.djangoproject.com/
#
from django.contrib.auth.tokens import PasswordResetTokenGenerator

from accounts.models import Person


class AccountsActivationTokenGenerator(PasswordResetTokenGenerator):
    """
    Accounts token generator

    FIXME: the check_token(…) method should be implemented in order to invalidate old tokens
    """

    def _make_hash_value(self, user: Person, timestamp: int) -> str:
        """
        Make the value that will be hashed in order to generate the token.

        .. note:: The user.password value is not used because of password salting.

        :param user: the user for which it is necessary to generate a token
        :type user: Person
        :param timestamp: a timestamp value
        :type timestamp: int
        :return: the value to hash
        :rtype: str
        """
        return str(user.pk) + user.username + str(timestamp) + str(user.is_active)
